/***************************************************************
 * Name:      checkBoxes.cpp
 * Purpose:   Code for Dialog spinControl
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-09
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "checkBoxes.h"

wxBEGIN_EVENT_TABLE(checkBoxes, wxDialog)
    EVT_CLOSE(checkBoxes::OnClose)
    EVT_CHECKBOX(idCheckBoxA, checkBoxes::OnActivo)
    EVT_CHECKBOX(id3Estados1, checkBoxes::On3Estados1)
    EVT_CHECKBOX(id3Estados2, checkBoxes::On3Estados2)
wxEND_EVENT_TABLE()

checkBoxes::checkBoxes(wxWindow *wnd, datosCheckBoxes &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de checkboxes")), data(datos), activo(true)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxGenericValidator val1(&data.check1);

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_checkBox1 = new wxCheckBox(this, idCheckBox, _T("Opción 1"), wxDefaultPosition, wxSize(200, wxDefaultCoord), wxCHK_2STATE, val1);
    boxHorizontal->Add(m_checkBox1, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_activar = new wxCheckBox(this, idCheckBoxA, _T("Activar"), wxDefaultPosition, wxSize(200, wxDefaultCoord), wxCHK_2STATE);
    boxHorizontal->Add(m_activar, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());
    m_activar->SetValue(data.check3 != wxCHK_UNDETERMINED);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_3estados1 = new wxCheckBox(this, id3Estados1, _T("3 estados auto"), wxDefaultPosition, wxSize(200, wxDefaultCoord), wxCHK_3STATE);
    boxHorizontal->Add(m_3estados1, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());
    m_3estados1->Set3StateValue(data.check3);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_3estados2 = new wxCheckBox(this, id3Estados2, _T("3 estados auto"), wxDefaultPosition, wxSize(200, wxDefaultCoord), wxCHK_3STATE | wxCHK_ALLOW_3RD_STATE_FOR_USER);
    boxHorizontal->Add(m_3estados2, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());
    m_3estados2->Set3StateValue(data.check4);

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

checkBoxes::~checkBoxes()
{
    //dtor
}

void checkBoxes::OnClose(wxCloseEvent& event) {
    Destroy();
}

void checkBoxes::OnActivo(wxCommandEvent& event) {
    if(m_activar->IsChecked())
        m_3estados1->Set3StateValue(wxCHK_UNCHECKED);
    else {
        data.check3 = wxCHK_UNDETERMINED;
        m_3estados1->Set3StateValue(data.check3);
    }
}

void checkBoxes::On3Estados1(wxCommandEvent& event) {
    data.check3 = m_3estados1->Get3StateValue();
    if(data.check3 == wxCHK_UNDETERMINED)
        m_activar->SetValue(wxCHK_UNCHECKED);
    else
        m_activar->SetValue(wxCHK_CHECKED);
}

void checkBoxes::On3Estados2(wxCommandEvent& event) {
    data.check4 = m_3estados2->Get3StateValue();
}
